from django.db import models
from django.contrib.auth.models import User
from django.db.models.signals import post_save
from django.utils.translation import ugettext_lazy as _

"""
This will attach a pirate party member data specific profile
to the ordinary User model in Django.
"""

class PirateWebProfile(models.Model):
    user = models.OneToOneField(User, related_name = 'pirateweb',
                                unique=True, verbose_name=_('user'))
    memberid = models.IntegerField(null=True, verbose_name=_('member id'))
    name = models.CharField(max_length=255, null=True, verbose_name=_('name'))
    mail = models.CharField(max_length=255, null=True, verbose_name=_('email'))
    phone = models.CharField(max_length=255, null=True, verbose_name=_('phone'))

    def is_member(self):
        return self.memberid > 0

    def __unicode__(self):
        return self.user.username

def create_profile(sender, instance=None, **kwargs):
    if instance is None:
        return
    profile, created = PirateWebProfile.objects.get_or_create(user=instance)

post_save.connect(create_profile, sender=User)
