from django.http import HttpResponseRedirect
from django.contrib.auth.models import User, AnonymousUser
from django.contrib.auth import authenticate, login
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _
from django.views.generic.simple import direct_to_template
from utils import validate_ticket
from forms import RegistrationForm

def _update_user_profile(user, pwuser):
    user.pirateweb.memberid = pwuser['id']
    user.pirateweb.name = pwuser['name']
    user.pirateweb.phone = pwuser['phone']
    user.pirateweb.mail = pwuser['email']

def verify(request):
    if request.GET['result'] != 'success':
        assert False
        return HttpResponseRedirect(reverse('acct_login'))

    pwuser = validate_ticket(ticket=request.GET['ticket'])
    if not pwuser:
        return HttpResponseRedirect(reverse('acct_login'))

    request.session["_pw_id"] = pwuser["id"]
    request.session["_pw_name"] = pwuser["name"]
    request.session["_pw_handle"] = pwuser["handle"]
    request.session["_pw_phone"] = pwuser["phone"]
    request.session["_pw_email"] = pwuser["email"]
    request.pwuser = pwuser

    if request.user.is_authenticated():
        _update_user_profile(request.user, request.pwuser)
        request.user.pirateweb.save()
        request.user.message_set.create(message=_(
                "Your PirateWeb account has successfully been associated!"))
        return HttpResponseRedirect(reverse('pirateweb_association'))
    else:
        user = authenticate(memberid=pwuser['id'])
        if user:
            login(request, user)
            return HttpResponseRedirect(reverse('home'))
        else:
            return HttpResponseRedirect(reverse('pirateweb_register'))

def register(request):
    assert request.pwuser or request.user is AnonymousUser
    if request.method == 'POST':
        form = RegistrationForm(request.POST)
        if form.is_valid():
            user = User.objects.create(
                username=form.cleaned_data['username'])
            user.save()
            _update_user_profile(user, request.pwuser)
            user.pirateweb.save()
            user = authenticate(memberid=request.pwuser['id'])
            login(request, user)
            return HttpResponseRedirect(reverse('home'))
    else:
        form = RegistrationForm()
    return direct_to_template(request, 'pirateweb/register.html', {
            'pwuser': request.pwuser,
            'form': form})

